# IBM Generative AI Initial Authors
- [Onkar Bhardwaj](https://github.com/onkarbhardwaj)
- [Veronique Demers](https://github.com/vedem1192)
- [James Sutton](https://github.com/jpwsutton)
- [Ja Young Lee](https://github.com/jayolee)
- [Mírian Silva](https://github.com/mirianfsilva)
- [Mairead O'Neill](https://github.com/moneill0)
- [Lee Martie](https://github.com/133martie)
- Ana Fucs

# IBM Generative AI Active Maintainers
- [Onkar Bhardwaj](https://github.com/onkarbhardwaj), onkarbhardwaj@ibm.com
- [Veronique Demers](https://github.com/vedem1192), vdemers@ibm.com
- [James Sutton](https://github.com/jpwsutton), james.sutton@uk.ibm.com
- [Ja Young Lee](https://github.com/jayolee), younglee@ibm.com
- [Mírian Silva](https://github.com/mirianfsilva), mirianfrsilva@ibm.com
- [Mairead O'Neill](https://github.com/moneill0), moneill@ibm.com

# Open-source Advocates
- [Adriana Meza Soria](https://github.com/ameza13), adriana.meza.soria@ibm.com
